@@ -7,12 +7,10 @@
  * @Author  Almsaeed Studio
  * @Support <http://www.almsaeedstudio.com>
  * @Email   <support@almsaeedstudio.com>
- * @version 2.1.2
+ * @version 2.3.2
  * @license MIT <http://opensource.org/licenses/MIT>
  */
 
-'use strict';
-
 //Make sure jQuery has been loaded before app.js
 if (typeof jQuery === "undefined") {
   throw new Error("AdminLTE requires jQuery");
@@ -41,7 +39,7 @@ $.AdminLTE.options = {
   navbarMenuSlimscroll: true,
   navbarMenuSlimscrollWidth: "3px", //The width of the scroll bar
   navbarMenuHeight: "200px", //The height of the inner menu
-  //General animation speed for JS animated elements such as box collapse/expand and 
+  //General animation speed for JS animated elements such as box collapse/expand and
   //sidebar treeview slide up/down. This options accepts an integer as milliseconds,
   //'fast', 'normal', or 'slow'
   animationSpeed: 500,
@@ -140,11 +138,16 @@ $.AdminLTE.options = {
  * options above.
  */
 $(function () {
+  "use strict";
+
+  //Fix for IE page transitions
+  $("body").removeClass("hold-transition");
+
   //Extend options if external options exist
   if (typeof AdminLTEOptions !== "undefined") {
     $.extend(true,
-            $.AdminLTE.options,
-            AdminLTEOptions);
+        $.AdminLTE.options,
+        AdminLTEOptions);
   }
 
   //Easy access to options
@@ -197,7 +200,7 @@ $(function () {
 
   //Activate direct chat widget
   if (o.directChat.enable) {
-    $(o.directChat.contactToggleSelector).on('click', function () {
+    $(document).on('click', o.directChat.contactToggleSelector, function () {
       var box = $(this).parents('.direct-chat').first();
       box.toggleClass('direct-chat-contacts-open');
     });
@@ -224,7 +227,7 @@ $(function () {
  * All AdminLTE functions are implemented below.
  */
 function _init() {
-
+  'use strict';
   /* Layout
    * ======
    * Fixes the layout height in case min-height fails.
@@ -279,8 +282,8 @@ function _init() {
           $(".sidebar").slimScroll({destroy: true}).height("auto");
         }
         return;
-      } else if (typeof $.fn.slimScroll == 'undefined' && console) {
-        console.error("Error: the fixed layout requires the slimscroll plugin!");
+      } else if (typeof $.fn.slimScroll == 'undefined' && window.console) {
+        window.console.error("Error: the fixed layout requires the slimscroll plugin!");
       }
       //Enable slimscroll for fixed layout
       if ($.AdminLTE.options.sidebarSlimScroll) {
@@ -311,20 +314,23 @@ function _init() {
       var screenSizes = $.AdminLTE.options.screenSizes;
 
       //Enable sidebar toggle
-      $(toggleBtn).on('click', function (e) {
+      $(document).on('click', toggleBtn, function (e) {
         e.preventDefault();
 
         //Enable sidebar push menu
         if ($(window).width() > (screenSizes.sm - 1)) {
-          $("body").toggleClass('sidebar-collapse');
+          if ($("body").hasClass('sidebar-collapse')) {
+            $("body").removeClass('sidebar-collapse').trigger('expanded.pushMenu');
+          } else {
+            $("body").addClass('sidebar-collapse').trigger('collapsed.pushMenu');
+          }
         }
         //Handle sidebar push menu for small screens
         else {
           if ($("body").hasClass('sidebar-open')) {
-            $("body").removeClass('sidebar-open');
-            $("body").removeClass('sidebar-collapse')
+            $("body").removeClass('sidebar-open').removeClass('sidebar-collapse').trigger('collapsed.pushMenu');
           } else {
-            $("body").addClass('sidebar-open');
+            $("body").addClass('sidebar-open').trigger('expanded.pushMenu');
           }
         }
       });
@@ -338,11 +344,10 @@ function _init() {
 
       //Enable expand on hover for sidebar mini
       if ($.AdminLTE.options.sidebarExpandOnHover
-              || ($('body').hasClass('fixed')
-                      && $('body').hasClass('sidebar-mini'))) {
+          || ($('body').hasClass('fixed')
+          && $('body').hasClass('sidebar-mini'))) {
         this.expandOnHover();
       }
-
     },
     expandOnHover: function () {
       var _this = this;
@@ -350,14 +355,14 @@ function _init() {
       //Expand sidebar on hover
       $('.main-sidebar').hover(function () {
         if ($('body').hasClass('sidebar-mini')
-                && $("body").hasClass('sidebar-collapse')
-                && $(window).width() > screenWidth) {
+            && $("body").hasClass('sidebar-collapse')
+            && $(window).width() > screenWidth) {
           _this.expand();
         }
       }, function () {
         if ($('body').hasClass('sidebar-mini')
-                && $('body').hasClass('sidebar-expanded-on-hover')
-                && $(window).width() > screenWidth) {
+            && $('body').hasClass('sidebar-expanded-on-hover')
+            && $(window).width() > screenWidth) {
           _this.collapse();
         }
       });
@@ -383,13 +388,13 @@ function _init() {
   $.AdminLTE.tree = function (menu) {
     var _this = this;
     var animationSpeed = $.AdminLTE.options.animationSpeed;
-    $(menu).on('click', "li a", function (e) {
+    $(menu).on('click', 'li a', function (e) {
       //Get the clicked link and the next element
       var $this = $(this);
       var checkElement = $this.next();
 
       //Check if the next element is a menu and is visible
-      if ((checkElement.is('.treeview-menu')) && (checkElement.is(':visible'))) {
+      if ((checkElement.is('.treeview-menu')) && (checkElement.is(':visible')) && (!$('body').hasClass('sidebar-collapse'))) {
         //Close the menu
         checkElement.slideUp(animationSpeed, function () {
           checkElement.removeClass('menu-open');
@@ -450,7 +455,7 @@ function _init() {
         e.preventDefault();
         //If the sidebar is not open
         if (!sidebar.hasClass('control-sidebar-open')
-                && !$('body').hasClass('control-sidebar-open')) {
+            && !$('body').hasClass('control-sidebar-open')) {
           //Open the sidebar
           _this.open(sidebar, o.slide);
         } else {
@@ -462,7 +467,7 @@ function _init() {
       var bg = $(".control-sidebar-bg");
       _this._fix(bg);
 
-      //If the body has a fixed layout, make the control sidebar fixed      
+      //If the body has a fixed layout, make the control sidebar fixed
       if ($('body').hasClass('fixed')) {
         _this._fixForFixed(sidebar);
       } else {
@@ -474,12 +479,11 @@ function _init() {
     },
     //Open the control sidebar
     open: function (sidebar, slide) {
-      var _this = this;
       //Slide over content
       if (slide) {
         sidebar.addClass('control-sidebar-open');
       } else {
-        //Push the content by adding the open class to the body instead 
+        //Push the content by adding the open class to the body instead
         //of the sidebar itself
         $('body').addClass('control-sidebar-open');
       }
@@ -532,10 +536,10 @@ function _init() {
   $.AdminLTE.boxWidget = {
     selectors: $.AdminLTE.options.boxWidgetOptions.boxWidgetSelectors,
     icons: $.AdminLTE.options.boxWidgetOptions.boxWidgetIcons,
-    animationSpeed: $.AdminLTE.options.animationSpeed,    
+    animationSpeed: $.AdminLTE.options.animationSpeed,
     activate: function (_box) {
       var _this = this;
-      if (! _box) {
+      if (!_box) {
         _box = document; // activate all boxes per default
       }
       //Listen for collapse event triggers
@@ -555,12 +559,12 @@ function _init() {
       //Find the box parent
       var box = element.parents(".box").first();
       //Find the body and the footer
-      var box_content = box.find("> .box-body, > .box-footer");
+      var box_content = box.find("> .box-body, > .box-footer, > form  >.box-body, > form > .box-footer");
       if (!box.hasClass("collapsed-box")) {
         //Convert minus into plus
         element.children(":first")
-                .removeClass(_this.icons.collapse)
-                .addClass(_this.icons.open);
+            .removeClass(_this.icons.collapse)
+            .addClass(_this.icons.open);
         //Hide the content
         box_content.slideUp(_this.animationSpeed, function () {
           box.addClass("collapsed-box");
@@ -569,15 +573,8 @@ function _init() {
       } else {
         //Convert plus into minus
         element.children(":first")
-                .removeClass(_this.icons.open)
-                .addClass(_this.icons.collapse);
-
-        // Techinically, it should be 'show' which is triggered here, and
-        // 'shown' which is triggered later. However, this works better because
-        // of the slow expansion transition -- the box would fully expand, and
-        // only then trigger 'shown', which then results in an update of the
-        // content. This would allow users to see the old content during the
-        // expansion.
+            .removeClass(_this.icons.open)
+            .addClass(_this.icons.collapse);
         box.trigger("shown.bs.collapse");
         //Show the content
         box_content.slideDown(_this.animationSpeed, function () {
@@ -585,7 +582,7 @@ function _init() {
         });
       }
     },
-    remove: function (element) {     
+    remove: function (element) {
       //Find the box parent
       var box = element.parents(".box").first();
       box.slideUp(this.animationSpeed);
@@ -610,6 +607,8 @@ function _init() {
  */
 (function ($) {
 
+  "use strict";
+
   $.fn.boxRefresh = function (options) {
 
     // Render options
@@ -620,8 +619,10 @@ function _init() {
       source: "",
       //Callbacks
       onLoadStart: function (box) {
+        return box;
       }, //Right after the button has been clicked
       onLoadDone: function (box) {
+        return box;
       } //When the source has been loaded
 
     }, options);
@@ -632,8 +633,8 @@ function _init() {
     return this.each(function () {
       //if a source is specified
       if (settings.source === "") {
-        if (console) {
-          console.log("Please specify a source first - boxRefresh()");
+        if (window.console) {
+          window.console.log("Please specify a source first - boxRefresh()");
         }
         return;
       }
@@ -673,21 +674,35 @@ function _init() {
 
 })(jQuery);
 
-/*
- * EXPLICIT BOX ACTIVATION
+ /*
+ * EXPLICIT BOX CONTROLS
  * -----------------------
  * This is a custom plugin to use with the component BOX. It allows you to activate
- * a box inserted in the DOM after the app.js was loaded.
+ * a box inserted in the DOM after the app.js was loaded, toggle and remove box.
  *
  * @type plugin
  * @usage $("#box-widget").activateBox();
+ * @usage $("#box-widget").toggleBox();
+ * @usage $("#box-widget").removeBox();
  */
 (function ($) {
 
+  'use strict';
+
   $.fn.activateBox = function () {
     $.AdminLTE.boxWidget.activate(this);
   };
 
+  $.fn.toggleBox = function(){
+    var button = $($.AdminLTE.boxWidget.selectors.collapse, this);
+    $.AdminLTE.boxWidget.collapse(button);
+  };
+
+  $.fn.removeBox = function(){
+    var button = $($.AdminLTE.boxWidget.selectors.remove, this);
+    $.AdminLTE.boxWidget.remove(button);
+  };
+
 })(jQuery);
 
 /*
@@ -700,38 +715,46 @@ function _init() {
  */
 (function ($) {
 
+  'use strict';
+
   $.fn.todolist = function (options) {
     // Render options
     var settings = $.extend({
       //When the user checks the input
       onCheck: function (ele) {
+        return ele;
       },
       //When the user unchecks the input
       onUncheck: function (ele) {
+        return ele;
       }
     }, options);
 
     return this.each(function () {
 
       if (typeof $.fn.iCheck != 'undefined') {
-        $('input', this).on('ifChecked', function (event) {
+        $('input', this).on('ifChecked', function () {
           var ele = $(this).parents("li").first();
           ele.toggleClass("done");
           settings.onCheck.call(ele);
         });
 
-        $('input', this).on('ifUnchecked', function (event) {
+        $('input', this).on('ifUnchecked', function () {
           var ele = $(this).parents("li").first();
           ele.toggleClass("done");
           settings.onUncheck.call(ele);
         });
       } else {
-        $('input', this).on('change', function (event) {
+        $('input', this).on('change', function () {
           var ele = $(this).parents("li").first();
           ele.toggleClass("done");
-          settings.onCheck.call(ele);
+          if ($('input', ele).is(":checked")) {
+            settings.onCheck.call(ele);
+          } else {
+            settings.onUncheck.call(ele);
+          }
         });
       }
     });
   };
-}(jQuery));
\ No newline at end of file
+}(jQuery));
